@@ -114,7 +114,7 @@ def load_and_fix_json(json_path):
             sys.exit(1)
 
 def get_text_from_editor(config, template=""):
-    tmpfile = os.path.join(tempfile.gettempdir(), "jrnl")
+    tmpfile = os.path.join(tempfile.mktemp(prefix="jrnl"))
     with codecs.open(tmpfile, 'w', "utf-8") as f:
         if template:
             f.write(template)
